--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.Rendering.OpenGL.Raw.EXT.BlendSubtract
-- Copyright   :  (c) Sven Panne 2015
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- The <https://www.opengl.org/registry/specs/EXT/blend_subtract.txt EXT_blend_subtract> extension.
--
--------------------------------------------------------------------------------

module Graphics.Rendering.OpenGL.Raw.EXT.BlendSubtract (
  -- * Enums
  gl_FUNC_REVERSE_SUBTRACT_EXT,
  gl_FUNC_SUBTRACT_EXT
) where

import Graphics.Rendering.OpenGL.Raw.Tokens
